Subject: [bug#70024] [PATCH core-updates 3/4] gnu: enchant: Improve package style.

From: Nicolas Goaziou <[email-masked]>
Date: Wed, 27 Mar 2024 10:40:40 +0100

* gnu/packages/enchant.scm (enchant)[arguments]: Use G-expressions.
[native-inputs]: Drop input labels.
[description]: Be more informative and less technical.

Change-Id: I908fbbfcdc9f21beb1d6e05eec2dbc154b429831
---
 gnu/packages/enchant.scm | 29 ++++++++++++++---------------
 1 file changed, 14 insertions(+), 15 deletions(-)

diff --git a/gnu/packages/enchant.scm b/gnu/packages/enchant.scm
index ca44b7c24d..417b5ce2e1 100644
--- a/gnu/packages/enchant.scm
+++ b/gnu/packages/enchant.scm
@@ -32,6 +32,7 @@ (define-module (gnu packages enchant)
   #:use-module (gnu packages perl)
   #:use-module (gnu packages pkg-config)
   #:use-module (gnu packages version-control)
+  #:use-module (guix gexp)
   #:use-module (guix packages)
   #:use-module (guix git-download)
   #:use-module (guix download)
@@ -91,29 +92,27 @@ (define-public enchant
                 "1bn7z8155czgzlnq2n4c915cl1vd3v95h1bghic3szy7c8q94rgm"))))
     (build-system gnu-build-system)
     (arguments
-     '(#:configure-flags '("--disable-static"
-                           ;; Tests require a relocatable build.
-                           "--enable-relocatable")))
+     (list
+      #:configure-flags
+      #~(list"--disable-static"
+             ;; Tests require a relocatable build.
+             "--enable-relocatable")))
     (inputs
      (list aspell hunspell))
     (propagated-inputs
      ;; Required by enchant.pc.
      (list glib))
     (native-inputs
-     `(("glib:bin" ,glib "bin")
-       ("groff" ,groff)
-       ("pkg-config" ,pkg-config)
-       ("unittest-cpp" ,unittest-cpp)))
+     (list `(,glib "bin") groff pkg-config unittest-cpp))
     (synopsis "Multi-backend spell-checking library wrapper")
     (description
-      "On the surface, Enchant appears to be a generic spell checking library.
-Looking closer, you'll see the Enchant is more-or-less a fancy wrapper around
-the dlopen() system call.
-
-Enchant steps in to provide uniformity and conformity on top of these libraries,
-and implement certain features that may be lacking in any individual provider
-library.  Everything should \"just work\" for any and every definition of \"just
-working\".")
+     "Enchant is a library---and command-line program---that wraps a number of
+different spelling libraries and programs with a consistent interface.  By
+using Enchant, you can use a wide range of spelling libraries, including some
+specialized for particular languages, without needing to program to each
+library's interface.  If it's not convenient to call a C library, you can
+access most of Enchant's functionality via the enchant program, which
+communicates over a pipe, like Ispell, and is indeed Ispell-compatible.")
     (home-page "https://abiword.github.io/enchant/")
     (license lgpl2.1+)))
 
-- 
2.41.0